import request from '@/utils/request'

export function study_list(query) {
  return request({
    url: '/system/business/study/list',
    method: 'get',
    params: query
  })
}

export function study_info(query) {
  return request({
    url: '/system/business/study/info',
    method: 'get',
    params: query
  })
}

export function study_save(data) {
  return request({
    url: '/system/business/study/save',
    method: 'post',
    data: data
  })
}

export function study_delete(data) {
  return request({
    url: '/system/business/study/delete',
    method: 'post',
    data: data
  })
}

export function study_jcgjList(query) {
  return request({
    url: '/system/business/study/jcgjList',
    method: 'get',
    params: query
  })
}

export function study_gd(data) {
  return request({
    url: '/system/business/study/gd',
    method: 'post',
    data: data
  })
}
export function study_checkSd(data) {
  return request({
    url: '/system/business/study/checkSd',
    method: 'post',
    data: data
  })
}
export function study_sd(data) {
  return request({
    url: '/system/business/study/sd',
    method: 'post',
    data: data
  })
}
export function study_js(data) {
  return request({
    url: '/system/business/study/js',
    method: 'post',
    data: data
  })
}
export function study_jd(data) {
  return request({
    url: '/system/business/study/jd',
    method: 'post',
    data: data
  })
}
export function study_jy(data) {
  return request({
    url: '/system/business/study/jy',
    method: 'post',
    data: data
  })
}
